@@ -20,6 +20,7 @@ def help():
     print(" torancell.mail(your mailaddress)")
     print(" list = torancell.handgen()")
     print(" torancell.shantenquiz()")
+    print(" torancell.tenhou()")
     
 def red():
     str = "かたい カラに つつまれているが なかみは やわらかいので つよい こうげきには たえられない。"
@@ -485,13 +486,13 @@ def intmahjong(i):
         return "pei"
     elif i==32:
         jihai.append(str(i-27))
-        return "haku"
+        return "hak"
     elif i==33:
         jihai.append(str(i-27))
-        return "hatu"
+        return "hat"
     elif i==34:
         jihai.append(str(i-27))
-        return "tyun"
+        return "tyu"
 def handgen(t=13):
     globalvar()
     i = list(range(1,136))
@@ -502,6 +503,7 @@ def handgen(t=13):
         t = t-1
         l.sort()
     inthand = list(map(ttt,l))
+    global hand
     hand = list(map(intmahjong,inthand))
     return hand
 
@@ -520,4 +522,31 @@ def shantenquiz():
     else:
         print("False, correct answer is "+str(result))
 
+def tenhou():
+    i = 1
+    while 1:
+        handgen(14)
+        jmans=''.join(mans)
+        jsous=''.join(sous)
+        jpins=''.join(pins)
+        jjihai=''.join(jihai)
+        shanten = Shanten()
+        tiles = TilesConverter.string_to_34_array(man=jmans,sou=jsous,pin=jpins,honors=jjihai)
+        result = shanten.calculate_shanten(tiles)
+        if result==-1:
+                if len(jihai)<4:
+                    print(str(hand)+"\t\t"+str(result)+" 天和 "+str(i)+"局目")
+                    return
+                else:
+                    print(str(hand)+"\t"+str(result)+" 天和 "+str(i)+"局目")
+                    return
+        else:
+            if i%1000==0:
+                if len(jihai)<4:
+                    print(str(hand)+"\t\t"+str(result)+"向牌 "+str(i)+"局目")
+                else:
+                    print(str(hand)+"\t"+str(result)+"向牌 "+str(i)+"局目")
+        i = i+1
 
+
+tenhou()
